@inline function _generate_word_cache()
    words = _get_non_capitalized_words()
    result = Dict{Vector{Char}, String}()
    for word in words
        result[collect(word)] = word
    end
    return result
end

@inline function _initialize_word_cache()
    lock(_word_cache_lock) do
        if isempty(_word_cache)
            new_word_cache = _generate_word_cache()
            for (key, value) in new_word_cache
                _word_cache[key] = value
            end
        end
        return nothing
    end
    return nothing
end

@inline function _read_word_cache()
    _initialize_word_cache()
    return lock(_word_cache_lock) do
        return deepcopy(_word_cache)
    end
end
